MaaRecordControllerCreate

Function MaaRecordControllerCreate 

pub unsafe extern "C" fn MaaRecordControllerCreate(
    inner: *mut MaaController,
    recording_path: *const c_char,
) -> *mut MaaController
@brief Create a record controller that wraps an existing controller and records all operations.

@param inner The inner controller to forward all operations to. Must not be null. The record controller does NOT take ownership of the inner controller. @param recording_path Path to the recording JSONL file to write. Screenshot images will be saved to a “{stem}-Screenshot” folder in the same directory as this file. The recorded file can be replayed using MaaReplayControllerCreate. @return The record controller handle, or nullptr on failure.