MaaWin32ScreencapMethod

Type Alias MaaWin32ScreencapMethod 

pub type MaaWin32ScreencapMethod = u64;
@brief Win32 screencap method

No bitwise OR, select ONE method only.

No default value. Client should choose one as default.

Different applications use different rendering methods, there is no universal solution.

MethodSpeedCompatibilityRequire AdminBackground SupportNotes
GDIFastMediumNoNo
FramePoolVery FastMediumNoYesRequires Windows 10 1903+
DXGI_DesktopDupVery FastLowNoNoDesktop duplication (full screen)
DXGI_DesktopDup_WindowVery FastLowNoNoDesktop duplication then crop
PrintWindowMediumMediumNoYes
ScreenDCFastHighNoNo

Note: FramePool and PrintWindow support pseudo-minimize — when the target window is minimized, they make it transparent and click-through, then restore it without activation, allowing screencap to continue without disturbing the user. Other screencap methods will fail when the target window is minimized.